@@ -14,17 +14,20 @@ def run_server(
     config: str = typer.Option(None, help="Path to the configuration file"),
     debug: bool = typer.Option(False, help="Enable debug mode (more verbose logging)"),
 ):
-    bootstrap(config or 'config.toml')
+    bootstrap(config or "config.toml")
     uvicorn.run(
         "lm_proxy.app:web_app",
         host=env.config.host,
         port=env.config.port,
         reload=env.config.dev_autoreload,
+        factory=True,
     )
 
 
 def web_app():
-    app = FastAPI(title="LM-Proxy", description="OpenAI-compatible proxy server for LLM inference")
+    app = FastAPI(
+        title="LM-Proxy", description="OpenAI-compatible proxy server for LLM inference"
+    )
     app.add_api_route(
         path="/v1/chat/completions",
         endpoint=chat_completions,
